<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Inserir els preus de l'any"; break;
case "Prezzi della":  				$messaggio = "Preus de la"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "soprannominata":  			$messaggio = "anomenada"; break;
case "Dal":  					$messaggio = "Des del"; break;
case "al":  					$messaggio = "fins el"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "insereix els preus nous"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "modifica els preus ja inserits"; break;
case "Costi aggiuntivi":  			$messaggio = "Suplements"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "Nom del nou suplement"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "sempre":  				$messaggio = "sempre"; break;
case "su richiesta":  				$messaggio = "\"on request\""; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "demanar per quant cal multiplicar"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "considera el cost final com a llit(s) addicional(s)"; break;
case "numero di settimane":  			$messaggio = "número de setmanes"; break;
case "numero di giorni":  			$messaggio = "número de dies"; break;
case "tutte":  					$messaggio = "totes"; break;
case "tutti":  					$messaggio = "tots"; break;
case "tutte meno una":  			$messaggio = "totes menys una"; break;
case "tutti meno uno":  			$messaggio = "tots menys un"; break;
case "chiedere":  				$messaggio = "demanar"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "considera el cost semtanal com a llit(s) addicional(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "considera el cost diari com a llit(s) addicional(s)"; break;
case "della tariffa arrotondato a":  		$messaggio = "de la tarifa arrodonit a"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considera el cost percentual com a llit(s) addicional(s)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Procedeix a la inserció del nou suplement"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "arrotondata a":  				$messaggio = "arrodonida a"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Inserir o modificar les arres"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "Mirar els preus ja inserits"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case "Si deve inserire la percentuale":  	$messaggio = "Cal especificar el percentatge"; break;
case "La caparra è stata modificata":  		$messaggio = "Les arres han estat modificades"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Cal espicificar quan s'aplicarà el cost de fi de lloguer"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Cal expecificar el nom del suplement"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "El suplement final"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "ja existeix. Pot ésser esborrat des de la pàgina amb tots els períodes i tarifes"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Si s'ha de demanar per quant s'ha de multiplicar, el suplement puntual no por ésser aplicat automàticament"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "Cal espicificar quan s'aplicarà el cost semtanal"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "Cal espicificar quan s'aplicarà el cost diari"; break;
case "e il numero di settimane":  		$messaggio = "i el número de setmanes"; break;
case "e il numero di giorni":  			$messaggio = "i el número de dies"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "Si cal demanar la quantitat de setmanes o per quant s'ha de multiplicar, llavors el suplement setmanal no es pot aplicar automàticament"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "Si cal demanar la quantitat de dies o per quant s'ha de multiplicar, llavors el suplement diari no es pot aplicar automàticament"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "El suplement semtanal"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "El suplement diari"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "Cal espicificar quan aplicar el cost percentual"; break;
case "e il valore dell'arrotondamento":		$messaggio = "i el valor al qual arrodonir-lo"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "Si cal demanar per quant s'ha de multiplicar, el suplement percentual no es pot aplicar automàticament"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "El suplement percentual"; break;
case "è stato inserito":  			$messaggio = "ha estat inserit"; break;
case "Nessun dato è stato inserito":  		$messaggio = "No s'ha inserit cap dada"; break;
case "Il soprannome della":  			$messaggio = "El nom de la"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "ja existeix, emprar el botó \"modifica preus ja inserits\" para canviar-ho, o no posar-ho a l'hora d'inserir preus a períodes nous"; break;
case "Il soprannome":  				$messaggio = "El nom"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "ja existeix, cal emprar-ne un altre"; break;
case "Le date del periodo numero":  		$messaggio = "Les dates del període número"; break;
case "sono sbagliate":  			$messaggio = "són errònies"; break;
case "Il periodo":  				$messaggio = "El període"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "es solapa sobre un altre període"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "Un preu del període número"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "ja existeix, emprar el botó \"modifica preus ja inserits\" para canviar-lo"; break;
case "è stato cambiato":  			$messaggio = "ha estat canviat"; break;
case "Il prezzo del periodo":  			$messaggio = "El preu del període"; break;
case "è stato inserito":  			$messaggio = "ha estat inserit"; break;
case "Il prezzo del periodo numero":  		$messaggio = "El preu del període número"; break;
case "è sbagliato":  				$messaggio = "és erroni"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "L'import del suplement puntual és erroni"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "L'import del suplement semtanal és erroni"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "L'import del suplement diari és erroni"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "L'import del suplement percentual és erroni"; break;
case "Inserzione per settimane":		$messaggio = "Inserció per setmanes"; break;
case "Inserzione per giorni":			$messaggio = "Inserció per dies"; break;
case "Inserzione per settimane":  		$messaggio = "Inserció per setmanes"; break;
case "Settimane dal":  				$messaggio = "Setmanes des del"; break;
case "Dom/Lun":  				$messaggio = "Diu/Dil"; break;
case "Lun/Mar":  				$messaggio = "Dil/Dim"; break;
case "Mar/Mer":  				$messaggio = "Dim/Dix"; break;
case "Mer/Gio":  				$messaggio = "Dix/Dij"; break;
case "Gio/Ven":  				$messaggio = "Dij/Div"; break;
case "Ven/Sab":  				$messaggio = "Div/Dis"; break;
case "Sab/Dom":  				$messaggio = "Dis/Diu"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "inserir o modificar els preus"; break;
case "Le date sono sbagliate":  		$messaggio = "Les dates són errònies"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "El format de l'import és erroni"; break;
case "I prezzi per le settimane dal":  		$messaggio = "Els preus de les setmanes des de"; break;
case "della <b>tariffa":  			$messaggio = "de la <b>tarifa"; break;
case "sono stati inseriti":  			$messaggio = "han estat inserits"; break;
case "si":  					$messaggio = "sí"; break;
case "no":  					$messaggio = "no"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "assignat automàticament amb tarifes"; break;
case "nessuna":  				$messaggio = "cap"; break;
case "scegliere":  				$messaggio = "escollir"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "mostrar la pàgina d'inserció de reserves"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Escull les tarifes amb les quals s'aplicarà automàticament el suplement <b>puntual</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Escull les tarifes amb les quals s'aplicarà automàticament el suplement <b>setmanal</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Escull les tarifes amb les quals s'aplicarà automàticament el suplement <b>diari</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Escull les tarifes amb les quals s'aplicarà automàticament el suplement <b>percentual</b>"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Tipus de suplement"; break;
case "unico":  					$messaggio = "puntual"; break;
case "settimanale":  				$messaggio = "setmanal"; break;
case "giornaliero":  				$messaggio = "diari"; break;
case "il prezzo totale":  			$messaggio = "el preu total"; break;
case "la caparra":  				$messaggio = "les arres"; break;
case "totale meno caparra":  			$messaggio = "total menys arres"; break;
case "minimo":  				$messaggio = "mínim"; break;
case "massimo":  				$messaggio = "màxim"; break;
case "esattamente":  				$messaggio = "exactament"; break;
case "settimane":  				$messaggio = "setmanes"; break;
case "giorni":  				$messaggio = "dies"; break;
case "Se possibile":  				$messaggio = "Si és possible"; break;
case "Sempre":  				$messaggio = "Sempre"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Associar a setmanes específiques de la reserva"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Associar a dies específics de la reserva"; break;
case "Tutte":  					$messaggio = "Totes"; break;
case "Tutti":  					$messaggio = "Tots"; break;
case "Tutte meno":  				$messaggio = "Totes menys"; break;
case "Tutti meno":  				$messaggio = "Tots menys"; break;
case "la prima":  				$messaggio = "la primera"; break;
case "il primo":  				$messaggio = "el primer"; break;
case "l'ultima":  				$messaggio = "l'última"; break;
case "l'ultimo":  				$messaggio = "l'últim"; break;
case "Chiedere":  				$messaggio = "Demanar"; break;
case "settimane sì":  				$messaggio = "setmanes sí"; break;
case "giorni sì":  				$messaggio = "dies sí"; break;
case "settimane no":  				$messaggio = "setmanes no"; break;
case "giorni no":  				$messaggio = "dies no"; break;
case "e":  					$messaggio = "i"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Dies de la setmana seleccionats"; break;
case "Lunedì":  				$messaggio = "Dilluns"; break;
case "Martedì":  				$messaggio = "Dimarts"; break;
case "Mercoledì":  				$messaggio = "Dimecres"; break;
case "Giovedì":  				$messaggio = "Dijous"; break;
case "Venerdì":  				$messaggio = "Divendres"; break;
case "Sabato":  				$messaggio = "Dissabte"; break;
case "Domenica":  				$messaggio = "Diumenge"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiplicar el cost per"; break;
case "Uno":  					$messaggio = "Un"; break;
case "Chiedere":  				$messaggio = "Demanar"; break;
case "Numero di persone":  			$messaggio = "Número de persones"; break;
case "Numero di persone totale":  		$messaggio = "Número total de persones"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "excloses les dels costos amb llits addicionals"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Períodes als quals és permès inserir el cost"; break;
case "In tutti":  				$messaggio = "A tots"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Només als períodes seleccionats"; break;
case "dal":  					$messaggio = "des de"; break;
case "Elimina un periodo":  			$messaggio = "Elimina un període"; break;
case "Aggiungi un periodo":  			$messaggio = "Afegeix un període"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si totes les setmanes de la reserva són dins dels períodes seleccionats"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si tots els dies de la reserva són dins dels períodes seleccionats"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "encara que només una setmana de la reserva sigui dins dels períodes seleccionats"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "encara que només un dia de la reserva sigui dins dels períodes seleccionats"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "aplicar el cost només a les setmanes on sigui permès dins de reserva"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "aplicar el cost només als dies on sigui permès dins de reserva"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Característiques del cost a mantenir quan es modifiqui una reserva"; break;
case "Valore percentuale":  			$messaggio = "Valor percentual"; break;
case "e settimane associate":  			$messaggio = "i setmanes associades"; break;
case "e giorni associati":  			$messaggio = "i dies associats"; break;
case "Assegnazione settimane":  		$messaggio = "Assignació semtanes"; break;
case "Assegnazione giorni":  			$messaggio = "Assignació dies"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Número pel qual és multiplicat"; break;
case "Periodi permessi":  			$messaggio = "Períodes permesos"; break;
case "Associazione alle tariffe":  		$messaggio = "Associació a les tarifes"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Mostrar a la pàgina d'inserció de reserves"; break;
case "Si":  					$messaggio = "Sí"; break;
case "No":  					$messaggio = "No"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Considera el suplement com a llit(s) addicional(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limitar la quantitat que és possible tenir simultàniament dins d'un mateix període"; break;
case "Valore del costo":  			$messaggio = "Valor del cost"; break;
case "fisso di":  				$messaggio = "fixe de"; break;
case "percentuale su":  			$messaggio = "percentual sobre"; break;
case "la tariffa":  				$messaggio = "la tarifa"; break;
case "indietro":  				$messaggio = "enrere"; break;
case "avanti":  				$messaggio = "endavant"; break;
case "del":  					$messaggio = "del"; break;
case "arrotondato a":  				$messaggio = "arrodonit a"; break;
case "Errore nei valori inseriti":  		$messaggio = "Error als valors inserits"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Assignar automàticament amb les tarifes seleccionades"; break;
case "Tariffe":  				$messaggio = "Tarifes"; break;
case "Il costo aggiuntivo":  			$messaggio = "El suplement"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Les setmanes a les quals s'aplicarà el cost"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Els dies als quals s'aplicarà el cost"; break;
case "uno":  					$messaggio = "un"; break;
case "NO":  					$messaggio = "NO"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Cost extra ja existent"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Tarifes incompatibles amb el cost"; break;
case "Tariffe incompatibili":  			$messaggio = "Tarifes incompatibles"; break;
case "dalla":  					$messaggio = "des de la"; break;
case "aggiungendo":  				$messaggio = "afegint"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "Els preus de la tarifa seleccionada han estat importats"; break;
case "importa":  				$messaggio = "importar"; break;
case "se selezionato mantenere anche":  	$messaggio = "si seleccionant mantenir també"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "Quan sigui possible, assignar automàticament si falten"; break;
case "meno di":  				$messaggio = "menys de"; break;
case "più di":  				$messaggio = "més de"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "dies fins a la data inicial de la reserva en el moment d'inserir-la"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "Quan sigui possible, assignar automàticament si s'insereixen"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "o més reserves simultàniament"; break;
case "Modifica il costo":  			$messaggio = "Modificar el cost"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Inserir un nou suplement anomenat"; break;
case "importando le caratteristiche da":	$messaggio = "important les seves característiques des de"; break;
case "Sempre in periodi permessi":  		$messaggio = "Sempre en períodes permesos"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Preu de la setmana sencera"; break;
case "Prezzi dei giorni":  			$messaggio = "Preus dels dies"; break;
case "tra":  					$messaggio = "entre"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Béns de l'inventari que cal descomptar quan s'insereixi el cost"; break;
case "Nessuno":  				$messaggio = "Cap"; break;
case "Beni selezionati":  			$messaggio = "Béns seleccionats"; break;
case "Aggiungi un bene":  			$messaggio = "Afegir un bé"; break;
case "Elimina un bene":  			$messaggio = "Suprimir un bé"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Eliminar els béns de l'inventari del magatzem"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Béns de l'inventari a eliminar"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Mostrar agrupat amb costos semblants de la mateixa categoria en inserció"; break;
case "Il tipo di applicazione della":  		$messaggio = "El tipus d'aplicació de la"; break;
case "per persona":  				$messaggio = "per persona"; break;
case "per settimana":  				$messaggio = "per setmana"; break;
case "per giorno":  				$messaggio = "per dia"; break;
case "La caparra è errata":  			$messaggio = "Les arres són errònies"; break;
case "è":  					$messaggio = "és"; break;
case "il":  					$messaggio = "el"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "sono":  					$messaggio = "són"; break;
case "Tasse":  					$messaggio = "Impostos"; break;
case "della tariffa":  				$messaggio = "de la tarifa"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Inserir o modificar els impostos"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Les comissions han estat modificades"; break;
case "Le commissioni sono errate":  		$messaggio = "Les comissions són errònies"; break;
case "Le tasse sono state modificate":  	$messaggio = "Els impostos han estat modificats"; break;
case "Le tasse sono errate":  			$messaggio = "Els impostos són erronis"; break;
case "Inserisci o modifica le commissioni normali":	$messaggio = "Inserir o modificar les comissions normals"; break;
case "Inserisci o modifica le commissioni in questo periodo":	$messaggio = "Inserir o modificar les comissions d'aquest període"; break;
case "Sulla":  					$messaggio = "Sobre la"; break;
case "al giorno":  				$messaggio = "per dia"; break;
case "alla settimana":  			$messaggio = "per setmana"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "l'import del cost inclou impostos"; break;
case "Categoria":  				$messaggio = "Categoria"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "el preu de la tarifa pels primers"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "el preu de la tarifa per les primeres"; break;
case "della":  					$messaggio = "de la"; break;
case "tariffa + sconto":  			$messaggio = "tarifa + descompte"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "tarifa + descompte + suplements"; break;
case "Nome della":  				$messaggio = "Nom de la"; break;
case "Cambia":  				$messaggio = "Canviar"; break;
case "prezzo per settimana":  			$messaggio = "preu per setmana"; break;
case "prezzo per giorno":  			$messaggio = "preu per dia"; break;
case "prezzo per persona per settimana":  	$messaggio = "preu per persona i per setmana"; break;
case "prezzo per persona per giorno":  		$messaggio = "preu per persona i per dia"; break;
case "p":  					$messaggio = "p"; break;
case "parte fissa della tariffa":  		$messaggio = "part fixa de la tarifa"; break;
case "parte per una persona della tariffa":  	$messaggio = "part per persona de la tarifa"; break;
case "Numero massimo":  			$messaggio = "Número màxim"; break;
case "0 se illimitato":  			$messaggio = "0 para il·limitat"; break;
case "meno":  					$messaggio = "menys"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "el cost serà zero si la suma és negativa"; break;
case "Combina con altri costi":			$messaggio = "Combinar amb altres costos"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "els costos combinables són mostrats tots junts amb el nom de la categoria i cadascun és inserit si és possible"; break;
case "opzionale":  				$messaggio = "opcional"; break;
case "Costi combinati":  			$messaggio = "Costos combinats"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Inserció ràpida d'un suplement nou per"; break;
case "permanenza minima":  			$messaggio = "estada mínima"; break;
case "letto aggiuntivo":  			$messaggio = "llit addicional"; break;
case "offerta speciale":  			$messaggio = "oferta especial"; break;
case "inserisci":  				$messaggio = "inserir"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Inserir el suplement"; break;
case "Numero minimo di giorni":  		$messaggio = "Número mínim de dies"; break;
case "Applicato alle tariffe":  		$messaggio = "Aplicar a les tarifes"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Períodes als quals s'aplica el cost"; break;
case "del prezzo di una persona":  		$messaggio = "del preu d'una persona"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "només per tarifes amb preus per persona"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Import del llit addicional"; break;
case "Valore dello sconto":  			$messaggio = "Import del descompte"; break;
case "del prezzo totale":  			$messaggio = "del preu total"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "Si la reserva te una duració de"; break;
case "o più giorni":  				$messaggio = "o més dies"; break;
case "Se":  					$messaggio = "Si"; break;
case "Se si inseriscono":  			$messaggio = "Si s'insereixen"; break;
case "a":  					$messaggio = "to"; break;
case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
case "della tar.":  				$messaggio = "of rate"; break;
case "di t.+s.":  				$messaggio = "of r.+d."; break;
case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
case "numero di neonati":  			$messaggio = "number of infants"; break;
case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
case "escludi":  				$messaggio = "exclude"; break;
case "includi solo":  				$messaggio = "include only"; break;
case "questi tipi":  				$messaggio = "these types"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
case "tariffe con":  				$messaggio = "rates with"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>